==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SortOptionsFluentImpl<A extends SortOptionsFluent<A>> extends BaseFluent<A> implements SortOptionsFluent<A>{
  public SortOptionsFluentImpl() {
  }
  public SortOptionsFluentImpl(SortOptions instance) {
    this.withLegacySortOptions(instance.getLegacySortOptions()); 
    this.withOrder(instance.getOrder()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private LegacySortOptionsBuilder legacySortOptions;
  private String order;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLegacySortOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public LegacySortOptions getLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  public LegacySortOptions buildLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  public A withLegacySortOptions(LegacySortOptions legacySortOptions) {
    _visitables.get("legacySortOptions").remove(this.legacySortOptions);
    if (legacySortOptions!=null){ this.legacySortOptions= new LegacySortOptionsBuilder(legacySortOptions); _visitables.get("legacySortOptions").add(this.legacySortOptions);} else { this.legacySortOptions = null; _visitables.get("legacySortOptions").remove(this.legacySortOptions); } return (A) this;
  }
  public Boolean hasLegacySortOptions() {
    return this.legacySortOptions != null;
  }
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptions() {
    return new SortOptionsFluentImpl.LegacySortOptionsNestedImpl();
  }
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item) {
    return new SortOptionsFluentImpl.LegacySortOptionsNestedImpl(item);
  }
  public SortOptionsFluent.LegacySortOptionsNested<A> editLegacySortOptions() {
    return withNewLegacySortOptionsLike(getLegacySortOptions());
  }
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptions() {
    return withNewLegacySortOptionsLike(getLegacySortOptions() != null ? getLegacySortOptions(): new LegacySortOptionsBuilder().build());
  }
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item) {
    return withNewLegacySortOptionsLike(getLegacySortOptions() != null ? getLegacySortOptions(): item);
  }
  public String getOrder() {
    return this.order;
  }
  public A withOrder(String order) {
    this.order=order; return (A) this;
  }
  public Boolean hasOrder() {
    return this.order != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SortOptionsFluentImpl that = (SortOptionsFluentImpl) o;
    if (legacySortOptions != null ? !legacySortOptions.equals(that.legacySortOptions) :that.legacySortOptions != null) return false;
    if (order != null ? !order.equals(that.order) :that.order != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(legacySortOptions,  order,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (legacySortOptions != null) { sb.append("legacySortOptions:"); sb.append(legacySortOptions + ","); }
    if (order != null) { sb.append("order:"); sb.append(order + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LegacySortOptionsNestedImpl<N> extends LegacySortOptionsFluentImpl<SortOptionsFluent.LegacySortOptionsNested<N>> implements SortOptionsFluent.LegacySortOptionsNested<N>,Nested<N>{
    LegacySortOptionsNestedImpl(LegacySortOptions item) {
      this.builder = new LegacySortOptionsBuilder(this, item);
    }
    LegacySortOptionsNestedImpl() {
      this.builder = new LegacySortOptionsBuilder(this);
    }
    LegacySortOptionsBuilder builder;
    public N and() {
      return (N) SortOptionsFluentImpl.this.withLegacySortOptions(builder.build());
    }
    public N endLegacySortOptions() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SortOptionsFluentImpl<A extends SortOptionsFluent<A>> extends BaseFluent<A> implements SortOptionsFluent<A>{
  public SortOptionsFluentImpl() {
  }
  public SortOptionsFluentImpl(SortOptions instance) {
    if (instance != null) {
      this.withLegacySortOptions(instance.getLegacySortOptions());
      this.withOrder(instance.getOrder());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private LegacySortOptionsBuilder legacySortOptions;
  private String order;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLegacySortOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public LegacySortOptions getLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  public LegacySortOptions buildLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  public A withLegacySortOptions(LegacySortOptions legacySortOptions) {
    _visitables.get("legacySortOptions").remove(this.legacySortOptions);
    if (legacySortOptions!=null){ this.legacySortOptions= new LegacySortOptionsBuilder(legacySortOptions); _visitables.get("legacySortOptions").add(this.legacySortOptions);} else { this.legacySortOptions = null; _visitables.get("legacySortOptions").remove(this.legacySortOptions); } return (A) this;
  }
  public Boolean hasLegacySortOptions() {
    return this.legacySortOptions != null;
  }
  public SortOptionsFluentImpl.LegacySortOptionsNested<A> withNewLegacySortOptions() {
    return new SortOptionsFluentImpl.LegacySortOptionsNestedImpl();
  }
  public SortOptionsFluentImpl.LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item) {
    return new SortOptionsFluentImpl.LegacySortOptionsNestedImpl(item);
  }
  public SortOptionsFluentImpl.LegacySortOptionsNested<A> editLegacySortOptions() {
    return withNewLegacySortOptionsLike(getLegacySortOptions());
  }
  public SortOptionsFluentImpl.LegacySortOptionsNested<A> editOrNewLegacySortOptions() {
    return withNewLegacySortOptionsLike(getLegacySortOptions() != null ? getLegacySortOptions(): new LegacySortOptionsBuilder().build());
  }
  public SortOptionsFluentImpl.LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item) {
    return withNewLegacySortOptionsLike(getLegacySortOptions() != null ? getLegacySortOptions(): item);
  }
  public String getOrder() {
    return this.order;
  }
  public A withOrder(String order) {
    this.order=order; return (A) this;
  }
  public Boolean hasOrder() {
    return this.order != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SortOptionsFluentImpl that = (SortOptionsFluentImpl) o;
    if (!java.util.Objects.equals(legacySortOptions, that.legacySortOptions)) return false;

    if (!java.util.Objects.equals(order, that.order)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(legacySortOptions,  order,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (legacySortOptions != null) { sb.append("legacySortOptions:"); sb.append(legacySortOptions + ","); }
    if (order != null) { sb.append("order:"); sb.append(order + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LegacySortOptionsNestedImpl<N> extends LegacySortOptionsFluentImpl<SortOptionsFluentImpl.LegacySortOptionsNested<N>> implements SortOptionsFluentImpl.LegacySortOptionsNested<N>,Nested<N>{
    LegacySortOptionsNestedImpl(LegacySortOptions item) {
      this.builder = new LegacySortOptionsBuilder(this, item);
    }
    LegacySortOptionsNestedImpl() {
      this.builder = new LegacySortOptionsBuilder(this);
    }
    LegacySortOptionsBuilder builder;
    public N and() {
      return (N) SortOptionsFluentImpl.this.withLegacySortOptions(builder.build());
    }
    public N endLegacySortOptions() {
      return and();
    }
    
  }
  
}
